==> haskell-parsers-0.12.3-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-parsers/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.3
id: parsers-0.12.3-e9ff529474e9ade28ca7d7edafd220d1
key: parse_EldVHQEJQybFnOXkdoyRBk
license: BSD3
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.LookAhead
    Text.Parser.Permutation Text.Parser.Expression Text.Parser.Token
    Text.Parser.Token.Style Text.Parser.Token.Highlight
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/parsers-0.12.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/parsers-0.12.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/parsers-0.12.3
hs-libraries: HSparsers-0.12.3-EldVHQEJQybFnOXkdoyRBk
depends:
    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base-orphans-0.5.1-066f51369735933a8c1cc4e054dd01ca
    charset-0.3.7.1-543137c1a84e9708652346da73519711
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
    scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parsers-0.12.3-8-armv7h.pkg.tar.xz: usr/share/haskell/haskell-parsers/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.3
id: parsers-0.12.3-39fdea4c999d2dce5f1305b594de4161
key: parse_CtATL5vXuTUDeN4kd0Ra9W
license: BSD3
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.LookAhead
    Text.Parser.Permutation Text.Parser.Expression Text.Parser.Token
    Text.Parser.Token.Style Text.Parser.Token.Highlight
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/parsers-0.12.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/parsers-0.12.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/parsers-0.12.3
hs-libraries: HSparsers-0.12.3-CtATL5vXuTUDeN4kd0Ra9W
depends:
    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base-orphans-0.5.3-27215a9428d23686c8514fbd3bba8ccb
    charset-0.3.7.1-07fa1295548c21364abbf3188fa2df38
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
    scientific-0.3.4.6-460bb668ffbf15e21b1a22bd826e372c
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
